"use strict";

const blackListedProjectNames = ["react", "test", "app"];
const {
  logger,
  doesDirectoryExist,
  installPackages
} = require("../utils/helperLoader");
const shell = require("shelljs");
const cwd = process.cwd();
const fluxGenerator = require("./flux");
const fs = require("fs");

module.exports = function(args, cb) {
  const name = args.name;
  let useFlux = false,
    packageList = [];

  // Check to see if folder already exists...
  if (doesDirectoryExist(cwd, name)) {
    logger(
      "error",
      "Directory or project already exists. Exiting generation process."
    );
  }

  if (blackListedProjectNames.indexOf(name) > -1)
    logger("error", "Your project name can not contain react, test or app.");

  // Install React APP
  logger("info", "Installing React App...");
  if (shell.exec(`create-react-app ${name}`).code !== 0) {
    logger("error", "Could not generate React Application.");
  } else {
    logger("success", "Successfully generated project. Happy Coding!");
  }

  // Add React-CLI Package
  packageList.push("@jdavalenti/react-cli");

  // Install Flux
  if (args.options.flux) {
    // Add flux package
    packageList.push("flux");
    packageList.push("object-assign");
    packageList.push("events");

    installPackages(name, packageList);

    args.options.directory = `${cwd}/${name}`;

    useFlux = true;

    // Create flux structure
    fluxGenerator(args, function() {});
  } else {
    installPackages(name, packageList);
  }

  // Generate react-cli-build.js
  fs.readFile(`${cwd}/blueprints/react-cli-build.js`, "utf8", function(
    err,
    data
  ) {
    if (err) {
      logger("error", "Could not read react-cli-build.js for installation.");
    }

    let result = data
      .replace(/__USE_FLUX__/g, useFlux)
      .replace(/__USE_PODS__/g, false);

    fs.writeFile(`${cwd}/${name}/react-cli-build.js`, result, function(err) {
      if (err)
        logger("error", "Could not save react-cli-build.js for project.");
    });
  });

  packageList = [];

  cb();
};
