"use strict";

const fs = require("fs");
const colors = require("colors");
const isInstalled = require("is-installed");
const shell = require("shelljs");
const decamelize = require("decamelize");
const camelcase = require("camelcase");

colors.setTheme({
  info: "green",
  white: "white",
  help: "cyan",
  warn: "yellow",
  error: "red"
});

module.exports.logger = function(type, message) {
  if (type === "error") {
    console.log(colors.red(`${message}`));
    return;
  } else if (type === "success") {
    console.log(colors.green(`${message}`));
    return;
  } else if (type === "info") {
    console.log(colors.cyan(`${message}`));
    return;
  }
  console.log(message);
};

module.exports.shouldUseYarn = isInstalled.sync("yarn");

module.exports.installPackages = function(projectName, packages) {
  let directory = `${projectName}`;
  if (!fs.existsSync(directory)) {
    console.log(
      colors.red(
        "Could not install required packages. The required project directory does not exist."
      )
    );
    process.exit(1);
  }

  let packagesJoined = packages.join(" ");
  console.log(colors.cyan(`Installing Required Packages (${packagesJoined})`));
  if (isInstalled.sync("yarn")) {
    if (
      shell.exec(`cd ${projectName}; yarn add ${packagesJoined}`).code !== 0
    ) {
      console.log(
        colors.red(
          "We were unable to install some packages. Check your yarn-error.log for more info."
        )
      );
      process.exit(1);
    }
  } else {
    if (shell.exec(`cd ${projectName}; npm i ${packagesJoined}`).code !== 0) {
      console.log(
        colors.red(
          "We were unable to install some packages. Check your yarn-error.log for more info."
        )
      );
      process.exit(1);
    }
  }
};

module.exports.doesDirectoryExist = function(path, folder) {
  return fs.exists(`${path}/${folder}`);
};

module.exports.makeDirectory = function(path, folder) {
  fs.mkdirSync(`${path}/${folder}`);
};

/**
 * We use this to validate that we're probably in a project
 */
module.exports.validProjectDirectory = function() {
  let valid = true;

  // Does react-cli-build.js exist?
  if (!fs.existsSync(`./react-cli-build.js`)) valid = false;

  if (!valid) {
    console.log(colors.red("You are not in a valid React-CLI project."));
    process.exit(1);
  }
};

module.exports.generateFileName = function(string, separator = "-") {
  return decamelize(string, separator);
};

module.exports.getPascalCase = function(string) {
  return camelcase(string, { pascalCase: true });
};
